pitchtools.HarmonicDiatonicIntervalClassSet
===========================================

.. autoclass:: abjad.tools.pitchtools.HarmonicDiatonicIntervalClassSet
   :members:
   :undoc-members:
   :show-inheritance:
